summaryrefslogtreecommitdiffstats
path: root/src/prefs.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 20:48:23 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 20:48:23 +0000
commit383adc283801b6238d8acfc750890613a63f8060 (patch)
treeaf3a65389067c05263db2ef4551a541501422998 /src/prefs.cpp
parentda7847adb43726079c7a4be1f06acbebe0bdde57 (diff)
downloadkima-383adc283801b6238d8acfc750890613a63f8060.tar.gz
kima-383adc283801b6238d8acfc750890613a63f8060.zip
TQt4 port kima
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kima@1239290 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/prefs.cpp')
-rw-r--r--src/prefs.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/src/prefs.cpp b/src/prefs.cpp
index ed1ec2b..cf17d22 100644
--- a/src/prefs.cpp
+++ b/src/prefs.cpp
@@ -11,28 +11,28 @@
#include "prefs.h"
-#include <qvariant.h>
-#include <qsplitter.h>
-#include <qheader.h>
+#include <tqvariant.h>
+#include <tqsplitter.h>
+#include <tqheader.h>
#include <klistview.h>
-#include <qwidgetstack.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqwidgetstack.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
/*
* Constructs a Prefs as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-Prefs::Prefs( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+Prefs::Prefs( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "Prefs" );
- PrefsLayout = new QVBoxLayout( this, 0, 6, "PrefsLayout");
+ PrefsLayout = new TQVBoxLayout( this, 0, 6, "PrefsLayout");
- splitter3 = new QSplitter( this, "splitter3" );
- splitter3->setOrientation( QSplitter::Horizontal );
+ splitter3 = new TQSplitter( this, "splitter3" );
+ splitter3->setOrientation( TQSplitter::Horizontal );
sourceListView = new KListView( splitter3, "sourceListView" );
sourceListView->addColumn( tr2i18n( "Source" ) );
@@ -40,13 +40,13 @@ Prefs::Prefs( QWidget* parent, const char* name, WFlags fl )
sourceListView->header()->setResizeEnabled( FALSE, sourceListView->header()->count() - 1 );
sourceListView->setResizeMode( KListView::AllColumns );
- widgetStack = new QWidgetStack( splitter3, "widgetStack" );
+ widgetStack = new TQWidgetStack( splitter3, "widgetStack" );
- WStackPage = new QWidget( widgetStack, "WStackPage" );
+ WStackPage = new TQWidget( widgetStack, "WStackPage" );
widgetStack->addWidget( WStackPage, 0 );
PrefsLayout->addWidget( splitter3 );
languageChange();
- resize( QSize(340, 73).expandedTo(minimumSizeHint()) );
+ resize( TQSize(340, 73).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
}
@@ -55,7 +55,7 @@ Prefs::Prefs( QWidget* parent, const char* name, WFlags fl )
*/
Prefs::~Prefs()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -11,28 +11,28 @@
/*
- * Constructs a Prefs as a child of 'parent', with the
+ * Constructs a Prefs as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/